"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Business:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _BusinessEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Business.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _Business.ValueType  # 0
    """未知类型"""

    STORY: _Business.ValueType  # 1
    """story业务"""

class Business(_Business, metaclass=_BusinessEnumTypeWrapper):
    """业务类型"""
    pass

UNKNOWN: Business.ValueType  # 0
"""未知类型"""

STORY: Business.ValueType  # 1
"""story业务"""

global___Business = Business


class _CodeType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _CodeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CodeType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NOCODE: _CodeType.ValueType  # 0
    """默认"""

    CODE264: _CodeType.ValueType  # 1
    """H.264"""

    CODE265: _CodeType.ValueType  # 2
    """H.265"""

class CodeType(_CodeType, metaclass=_CodeTypeEnumTypeWrapper):
    """编码类型"""
    pass

NOCODE: CodeType.ValueType  # 0
"""默认"""

CODE264: CodeType.ValueType  # 1
"""H.264"""

CODE265: CodeType.ValueType  # 2
"""H.265"""

global___CodeType = CodeType


class _ConfType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _ConfTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ConfType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NoType: _ConfType.ValueType  # 0
    """"""

    FLIPCONF: _ConfType.ValueType  # 1
    """镜像反转"""

    CASTCONF: _ConfType.ValueType  # 2
    """视频投屏"""

    FEEDBACK: _ConfType.ValueType  # 3
    """反馈"""

    SUBTITLE: _ConfType.ValueType  # 4
    """字幕"""

    PLAYBACKRATE: _ConfType.ValueType  # 5
    """播放速度"""

    TIMEUP: _ConfType.ValueType  # 6
    """定时停止播放"""

    PLAYBACKMODE: _ConfType.ValueType  # 7
    """播放方式"""

    SCALEMODE: _ConfType.ValueType  # 8
    """画面尺寸"""

    BACKGROUNDPLAY: _ConfType.ValueType  # 9
    """后台播放"""

    LIKE: _ConfType.ValueType  # 10
    """顶"""

    DISLIKE: _ConfType.ValueType  # 11
    """踩"""

    COIN: _ConfType.ValueType  # 12
    """投币"""

    ELEC: _ConfType.ValueType  # 13
    """充电"""

    SHARE: _ConfType.ValueType  # 14
    """分享"""

    SCREENSHOT: _ConfType.ValueType  # 15
    """截图"""

    LOCKSCREEN: _ConfType.ValueType  # 16
    """锁屏"""

    RECOMMEND: _ConfType.ValueType  # 17
    """推荐"""

    PLAYBACKSPEED: _ConfType.ValueType  # 18
    """倍速"""

    DEFINITION: _ConfType.ValueType  # 19
    """清晰度"""

    SELECTIONS: _ConfType.ValueType  # 20
    """选集"""

    NEXT: _ConfType.ValueType  # 21
    """下一集"""

    EDITDM: _ConfType.ValueType  # 22
    """编辑弹幕"""

    SMALLWINDOW: _ConfType.ValueType  # 23
    """小窗"""

    SHAKE: _ConfType.ValueType  # 24
    """播放震动"""

    OUTERDM: _ConfType.ValueType  # 25
    """外层面板弹幕设置"""

    INNERDM: _ConfType.ValueType  # 26
    """三点内弹幕设置"""

    PANORAMA: _ConfType.ValueType  # 27
    """全景"""

    DOLBY: _ConfType.ValueType  # 28
    """杜比"""

    COLORFILTER: _ConfType.ValueType  # 29
    """"""

class ConfType(_ConfType, metaclass=_ConfTypeEnumTypeWrapper):
    """设置类型"""
    pass

NoType: ConfType.ValueType  # 0
""""""

FLIPCONF: ConfType.ValueType  # 1
"""镜像反转"""

CASTCONF: ConfType.ValueType  # 2
"""视频投屏"""

FEEDBACK: ConfType.ValueType  # 3
"""反馈"""

SUBTITLE: ConfType.ValueType  # 4
"""字幕"""

PLAYBACKRATE: ConfType.ValueType  # 5
"""播放速度"""

TIMEUP: ConfType.ValueType  # 6
"""定时停止播放"""

PLAYBACKMODE: ConfType.ValueType  # 7
"""播放方式"""

SCALEMODE: ConfType.ValueType  # 8
"""画面尺寸"""

BACKGROUNDPLAY: ConfType.ValueType  # 9
"""后台播放"""

LIKE: ConfType.ValueType  # 10
"""顶"""

DISLIKE: ConfType.ValueType  # 11
"""踩"""

COIN: ConfType.ValueType  # 12
"""投币"""

ELEC: ConfType.ValueType  # 13
"""充电"""

SHARE: ConfType.ValueType  # 14
"""分享"""

SCREENSHOT: ConfType.ValueType  # 15
"""截图"""

LOCKSCREEN: ConfType.ValueType  # 16
"""锁屏"""

RECOMMEND: ConfType.ValueType  # 17
"""推荐"""

PLAYBACKSPEED: ConfType.ValueType  # 18
"""倍速"""

DEFINITION: ConfType.ValueType  # 19
"""清晰度"""

SELECTIONS: ConfType.ValueType  # 20
"""选集"""

NEXT: ConfType.ValueType  # 21
"""下一集"""

EDITDM: ConfType.ValueType  # 22
"""编辑弹幕"""

SMALLWINDOW: ConfType.ValueType  # 23
"""小窗"""

SHAKE: ConfType.ValueType  # 24
"""播放震动"""

OUTERDM: ConfType.ValueType  # 25
"""外层面板弹幕设置"""

INNERDM: ConfType.ValueType  # 26
"""三点内弹幕设置"""

PANORAMA: ConfType.ValueType  # 27
"""全景"""

DOLBY: ConfType.ValueType  # 28
"""杜比"""

COLORFILTER: ConfType.ValueType  # 29
""""""

global___ConfType = ConfType


class _Group:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _GroupEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Group.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UnknownGroup: _Group.ValueType  # 0
    """"""

    A: _Group.ValueType  # 1
    """"""

    B: _Group.ValueType  # 2
    """"""

    C: _Group.ValueType  # 3
    """"""

class Group(_Group, metaclass=_GroupEnumTypeWrapper):
    """"""
    pass

UnknownGroup: Group.ValueType  # 0
""""""

A: Group.ValueType  # 1
""""""

B: Group.ValueType  # 2
""""""

C: Group.ValueType  # 3
""""""

global___Group = Group


class _PlayErr:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _PlayErrEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PlayErr.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NoErr: _PlayErr.ValueType  # 0
    """"""

    WithMultiDeviceLoginErr: _PlayErr.ValueType  # 1
    """管控类型的错误码"""

class PlayErr(_PlayErr, metaclass=_PlayErrEnumTypeWrapper):
    """错误码"""
    pass

NoErr: PlayErr.ValueType  # 0
""""""

WithMultiDeviceLoginErr: PlayErr.ValueType  # 1
"""管控类型的错误码"""

global___PlayErr = PlayErr


class _VideoType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _VideoTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Unknown_VALUE: _VideoType.ValueType  # 0
    """"""

    FLV_VALUE: _VideoType.ValueType  # 1
    """flv格式"""

    DASH_VALUE: _VideoType.ValueType  # 2
    """dash格式"""

    MP4_VALUE: _VideoType.ValueType  # 3
    """mp4格式"""

class VideoType(_VideoType, metaclass=_VideoTypeEnumTypeWrapper):
    """视频类型"""
    pass

Unknown_VALUE: VideoType.ValueType  # 0
""""""

FLV_VALUE: VideoType.ValueType  # 1
"""flv格式"""

DASH_VALUE: VideoType.ValueType  # 2
"""dash格式"""

MP4_VALUE: VideoType.ValueType  # 3
"""mp4格式"""

global___VideoType = VideoType


class AB(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GLANCE_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    @property
    def glance(self) -> global___Glance:
        """"""
        pass
    group: builtins.int
    """"""

    def __init__(self,
        *,
        glance: typing.Optional[global___Glance] = ...,
        group: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["glance",b"glance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["glance",b"glance","group",b"group"]) -> None: ...
global___AB = AB

class ArcConf(google.protobuf.message.Message):
    """配置项"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IS_SUPPORT_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    EXTRA_CONTENT_FIELD_NUMBER: builtins.int
    is_support: builtins.bool
    """是否支持"""

    disabled: builtins.bool
    """"""

    @property
    def extra_content(self) -> global___ExtraContent:
        """"""
        pass
    def __init__(self,
        *,
        is_support: builtins.bool = ...,
        disabled: builtins.bool = ...,
        extra_content: typing.Optional[global___ExtraContent] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extra_content",b"extra_content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled",b"disabled","extra_content",b"extra_content","is_support",b"is_support"]) -> None: ...
global___ArcConf = ArcConf

class Chronos(google.protobuf.message.Message):
    """Chronos灰度管理"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MD5_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    md5: typing.Text
    """资源md5"""

    file: typing.Text
    """资源文件"""

    def __init__(self,
        *,
        md5: typing.Text = ...,
        file: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file",b"file","md5",b"md5"]) -> None: ...
global___Chronos = Chronos

class CloudConf(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SHOW_FIELD_NUMBER: builtins.int
    CONF_TYPE_FIELD_NUMBER: builtins.int
    FIELD_VALUE_FIELD_NUMBER: builtins.int
    CONF_VALUE_FIELD_NUMBER: builtins.int
    show: builtins.bool
    """是否展示功能"""

    conf_type: global___ConfType.ValueType
    """设置类型"""

    @property
    def field_value(self) -> global___FieldValue:
        """"""
        pass
    @property
    def conf_value(self) -> global___ConfValue:
        """"""
        pass
    def __init__(self,
        *,
        show: builtins.bool = ...,
        conf_type: global___ConfType.ValueType = ...,
        field_value: typing.Optional[global___FieldValue] = ...,
        conf_value: typing.Optional[global___ConfValue] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conf_value",b"conf_value","field_value",b"field_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conf_type",b"conf_type","conf_value",b"conf_value","field_value",b"field_value","show",b"show"]) -> None: ...
global___CloudConf = CloudConf

class ConfValue(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SWITCH_VAL_FIELD_NUMBER: builtins.int
    SELECTED_VAL_FIELD_NUMBER: builtins.int
    switch_val: builtins.bool
    """"""

    selected_val: builtins.int
    """"""

    def __init__(self,
        *,
        switch_val: builtins.bool = ...,
        selected_val: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["selected_val",b"selected_val","switch_val",b"switch_val","value",b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["selected_val",b"selected_val","switch_val",b"switch_val","value",b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["value",b"value"]) -> typing.Optional[typing_extensions.Literal["switch_val","selected_val"]]: ...
global___ConfValue = ConfValue

class DashItem(google.protobuf.message.Message):
    """dash条目"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    BASEURL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    BANDWIDTH_FIELD_NUMBER: builtins.int
    CODECID_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    FRAME_RATE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """清晰度"""

    baseUrl: typing.Text
    """主线流"""

    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """备用流"""
        pass
    bandwidth: builtins.int
    """带宽"""

    codecid: builtins.int
    """编码id"""

    md5: typing.Text
    """md5"""

    size: builtins.int
    """大小"""

    frame_rate: typing.Text
    """帧率"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        baseUrl: typing.Text = ...,
        backup_url: typing.Optional[typing.Iterable[typing.Text]] = ...,
        bandwidth: builtins.int = ...,
        codecid: builtins.int = ...,
        md5: typing.Text = ...,
        size: builtins.int = ...,
        frame_rate: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_url",b"backup_url","bandwidth",b"bandwidth","baseUrl",b"baseUrl","codecid",b"codecid","frame_rate",b"frame_rate","id",b"id","md5",b"md5","size",b"size"]) -> None: ...
global___DashItem = DashItem

class DashVideo(google.protobuf.message.Message):
    """dash视频流"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_URL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    BANDWIDTH_FIELD_NUMBER: builtins.int
    CODECID_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    AUDIOID_FIELD_NUMBER: builtins.int
    NO_REXCODE_FIELD_NUMBER: builtins.int
    FRAME_RATE_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    base_url: typing.Text
    """主线流"""

    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """备用流"""
        pass
    bandwidth: builtins.int
    """带宽"""

    codecid: builtins.int
    """编码id"""

    md5: typing.Text
    """md5"""

    size: builtins.int
    """大小"""

    audioId: builtins.int
    """伴音质量id"""

    no_rexcode: builtins.bool
    """是否非全二压"""

    frame_rate: typing.Text
    """码率"""

    width: builtins.int
    """宽度"""

    height: builtins.int
    """高度"""

    def __init__(self,
        *,
        base_url: typing.Text = ...,
        backup_url: typing.Optional[typing.Iterable[typing.Text]] = ...,
        bandwidth: builtins.int = ...,
        codecid: builtins.int = ...,
        md5: typing.Text = ...,
        size: builtins.int = ...,
        audioId: builtins.int = ...,
        no_rexcode: builtins.bool = ...,
        frame_rate: typing.Text = ...,
        width: builtins.int = ...,
        height: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audioId",b"audioId","backup_url",b"backup_url","bandwidth",b"bandwidth","base_url",b"base_url","codecid",b"codecid","frame_rate",b"frame_rate","height",b"height","md5",b"md5","no_rexcode",b"no_rexcode","size",b"size","width",b"width"]) -> None: ...
global___DashVideo = DashVideo

class DolbyItem(google.protobuf.message.Message):
    """杜比伴音信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _Type:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DolbyItem._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NONE: DolbyItem._Type.ValueType  # 0
        """NONE"""

        COMMON: DolbyItem._Type.ValueType  # 1
        """普通杜比音效"""

        ATMOS: DolbyItem._Type.ValueType  # 2
        """全景杜比音效"""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper):
        pass

    NONE: DolbyItem.Type.ValueType  # 0
    """NONE"""

    COMMON: DolbyItem.Type.ValueType  # 1
    """普通杜比音效"""

    ATMOS: DolbyItem.Type.ValueType  # 2
    """全景杜比音效"""


    TYPE_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    type: global___DolbyItem.Type.ValueType
    """杜比类型"""

    @property
    def audio(self) -> global___DashItem:
        """音频流"""
        pass
    def __init__(self,
        *,
        type: global___DolbyItem.Type.ValueType = ...,
        audio: typing.Optional[global___DashItem] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audio",b"audio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio",b"audio","type",b"type"]) -> None: ...
global___DolbyItem = DolbyItem

class Event(google.protobuf.message.Message):
    """事件"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SHAKE_FIELD_NUMBER: builtins.int
    @property
    def shake(self) -> global___Shake:
        """震动"""
        pass
    def __init__(self,
        *,
        shake: typing.Optional[global___Shake] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["shake",b"shake"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["shake",b"shake"]) -> None: ...
global___Event = Event

class ExtraContent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DISABLED_REASON_FIELD_NUMBER: builtins.int
    DISABLED_CODE_FIELD_NUMBER: builtins.int
    disabled_reason: typing.Text
    """"""

    disabled_code: builtins.int
    """"""

    def __init__(self,
        *,
        disabled_reason: typing.Text = ...,
        disabled_code: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled_code",b"disabled_code","disabled_reason",b"disabled_reason"]) -> None: ...
global___ExtraContent = ExtraContent

class FieldValue(google.protobuf.message.Message):
    """配置字段值"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SWITCH_FIELD_NUMBER: builtins.int
    switch: builtins.bool
    """开关"""

    def __init__(self,
        *,
        switch: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["switch",b"switch","value",b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["switch",b"switch","value",b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["value",b"value"]) -> typing.Optional[typing_extensions.Literal["switch"]]: ...
global___FieldValue = FieldValue

class FormatDescription(google.protobuf.message.Message):
    """清晰度描述"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    QUALITY_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    NEW_DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_DESC_FIELD_NUMBER: builtins.int
    SUPERSCRIPT_FIELD_NUMBER: builtins.int
    quality: builtins.int
    """清晰度"""

    format: typing.Text
    """清晰度格式"""

    description: typing.Text
    """清晰度描述"""

    new_description: typing.Text
    """新描述"""

    display_desc: typing.Text
    """选中态的清晰度描述"""

    superscript: typing.Text
    """选中态的清晰度描述的角标"""

    def __init__(self,
        *,
        quality: builtins.int = ...,
        format: typing.Text = ...,
        description: typing.Text = ...,
        new_description: typing.Text = ...,
        display_desc: typing.Text = ...,
        superscript: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description",b"description","display_desc",b"display_desc","format",b"format","new_description",b"new_description","quality",b"quality","superscript",b"superscript"]) -> None: ...
global___FormatDescription = FormatDescription

class Glance(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CAN_WATCH_FIELD_NUMBER: builtins.int
    TIMES_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    can_watch: builtins.bool
    """"""

    times: builtins.int
    """"""

    duration: builtins.int
    """"""

    def __init__(self,
        *,
        can_watch: builtins.bool = ...,
        times: builtins.int = ...,
        duration: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["can_watch",b"can_watch","duration",b"duration","times",b"times"]) -> None: ...
global___Glance = Glance

class PlayAbilityConf(google.protobuf.message.Message):
    """禁用功能配置"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BACKGROUND_PLAY_CONF_FIELD_NUMBER: builtins.int
    FLIP_CONF_FIELD_NUMBER: builtins.int
    CAST_CONF_FIELD_NUMBER: builtins.int
    FEEDBACK_CONF_FIELD_NUMBER: builtins.int
    SUBTITLE_CONF_FIELD_NUMBER: builtins.int
    PLAYBACK_RATE_CONF_FIELD_NUMBER: builtins.int
    TIME_UP_CONF_FIELD_NUMBER: builtins.int
    PLAYBACK_MODE_CONF_FIELD_NUMBER: builtins.int
    SCALE_MODE_CONF_FIELD_NUMBER: builtins.int
    LIKE_CONF_FIELD_NUMBER: builtins.int
    DISLIKE_CONF_FIELD_NUMBER: builtins.int
    COIN_CONF_FIELD_NUMBER: builtins.int
    ELEC_CONF_FIELD_NUMBER: builtins.int
    SHARE_CONF_FIELD_NUMBER: builtins.int
    SCREEN_SHOT_CONF_FIELD_NUMBER: builtins.int
    LOCK_SCREEN_CONF_FIELD_NUMBER: builtins.int
    RECOMMEND_CONF_FIELD_NUMBER: builtins.int
    PLAYBACK_SPEED_CONF_FIELD_NUMBER: builtins.int
    DEFINITION_CONF_FIELD_NUMBER: builtins.int
    SELECTIONS_CONF_FIELD_NUMBER: builtins.int
    NEXT_CONF_FIELD_NUMBER: builtins.int
    EDIT_DM_CONF_FIELD_NUMBER: builtins.int
    SMALL_WINDOW_CONF_FIELD_NUMBER: builtins.int
    SHAKE_CONF_FIELD_NUMBER: builtins.int
    OUTER_DM_CONF_FIELD_NUMBER: builtins.int
    INNERDMDISABLE_FIELD_NUMBER: builtins.int
    INNER_DM_CONF_FIELD_NUMBER: builtins.int
    DOLBY_CONF_FIELD_NUMBER: builtins.int
    COLOR_FILTER_CONF_FIELD_NUMBER: builtins.int
    @property
    def background_play_conf(self) -> global___CloudConf:
        """后台播放"""
        pass
    @property
    def flip_conf(self) -> global___CloudConf:
        """镜像反转"""
        pass
    @property
    def cast_conf(self) -> global___CloudConf:
        """投屏"""
        pass
    @property
    def feedback_conf(self) -> global___CloudConf:
        """反馈"""
        pass
    @property
    def subtitle_conf(self) -> global___CloudConf:
        """字幕"""
        pass
    @property
    def playback_rate_conf(self) -> global___CloudConf:
        """播放速度"""
        pass
    @property
    def time_up_conf(self) -> global___CloudConf:
        """定时停止"""
        pass
    @property
    def playback_mode_conf(self) -> global___CloudConf:
        """播放方式"""
        pass
    @property
    def scale_mode_conf(self) -> global___CloudConf:
        """画面尺寸"""
        pass
    @property
    def like_conf(self) -> global___CloudConf:
        """赞"""
        pass
    @property
    def dislike_conf(self) -> global___CloudConf:
        """踩"""
        pass
    @property
    def coin_conf(self) -> global___CloudConf:
        """投币"""
        pass
    @property
    def elec_conf(self) -> global___CloudConf:
        """充电"""
        pass
    @property
    def share_conf(self) -> global___CloudConf:
        """分享"""
        pass
    @property
    def screen_shot_conf(self) -> global___CloudConf:
        """截图"""
        pass
    @property
    def lock_screen_conf(self) -> global___CloudConf:
        """锁定"""
        pass
    @property
    def recommend_conf(self) -> global___CloudConf:
        """相关推荐"""
        pass
    @property
    def playback_speed_conf(self) -> global___CloudConf:
        """播放速度"""
        pass
    @property
    def definition_conf(self) -> global___CloudConf:
        """清晰度"""
        pass
    @property
    def selections_conf(self) -> global___CloudConf:
        """选集"""
        pass
    @property
    def next_conf(self) -> global___CloudConf:
        """下一集"""
        pass
    @property
    def edit_dm_conf(self) -> global___CloudConf:
        """编辑弹幕"""
        pass
    @property
    def small_window_conf(self) -> global___CloudConf:
        """小窗"""
        pass
    @property
    def shake_conf(self) -> global___CloudConf:
        """震动"""
        pass
    @property
    def outer_dm_conf(self) -> global___CloudConf:
        """外层面板弹幕设置"""
        pass
    @property
    def innerDmDisable(self) -> global___CloudConf:
        """三点内弹幕设置"""
        pass
    @property
    def inner_dm_conf(self) -> global___CloudConf:
        """一起看入口"""
        pass
    @property
    def dolby_conf(self) -> global___CloudConf:
        """杜比音效"""
        pass
    @property
    def color_filter_conf(self) -> global___CloudConf:
        """"""
        pass
    def __init__(self,
        *,
        background_play_conf: typing.Optional[global___CloudConf] = ...,
        flip_conf: typing.Optional[global___CloudConf] = ...,
        cast_conf: typing.Optional[global___CloudConf] = ...,
        feedback_conf: typing.Optional[global___CloudConf] = ...,
        subtitle_conf: typing.Optional[global___CloudConf] = ...,
        playback_rate_conf: typing.Optional[global___CloudConf] = ...,
        time_up_conf: typing.Optional[global___CloudConf] = ...,
        playback_mode_conf: typing.Optional[global___CloudConf] = ...,
        scale_mode_conf: typing.Optional[global___CloudConf] = ...,
        like_conf: typing.Optional[global___CloudConf] = ...,
        dislike_conf: typing.Optional[global___CloudConf] = ...,
        coin_conf: typing.Optional[global___CloudConf] = ...,
        elec_conf: typing.Optional[global___CloudConf] = ...,
        share_conf: typing.Optional[global___CloudConf] = ...,
        screen_shot_conf: typing.Optional[global___CloudConf] = ...,
        lock_screen_conf: typing.Optional[global___CloudConf] = ...,
        recommend_conf: typing.Optional[global___CloudConf] = ...,
        playback_speed_conf: typing.Optional[global___CloudConf] = ...,
        definition_conf: typing.Optional[global___CloudConf] = ...,
        selections_conf: typing.Optional[global___CloudConf] = ...,
        next_conf: typing.Optional[global___CloudConf] = ...,
        edit_dm_conf: typing.Optional[global___CloudConf] = ...,
        small_window_conf: typing.Optional[global___CloudConf] = ...,
        shake_conf: typing.Optional[global___CloudConf] = ...,
        outer_dm_conf: typing.Optional[global___CloudConf] = ...,
        innerDmDisable: typing.Optional[global___CloudConf] = ...,
        inner_dm_conf: typing.Optional[global___CloudConf] = ...,
        dolby_conf: typing.Optional[global___CloudConf] = ...,
        color_filter_conf: typing.Optional[global___CloudConf] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["background_play_conf",b"background_play_conf","cast_conf",b"cast_conf","coin_conf",b"coin_conf","color_filter_conf",b"color_filter_conf","definition_conf",b"definition_conf","dislike_conf",b"dislike_conf","dolby_conf",b"dolby_conf","edit_dm_conf",b"edit_dm_conf","elec_conf",b"elec_conf","feedback_conf",b"feedback_conf","flip_conf",b"flip_conf","innerDmDisable",b"innerDmDisable","inner_dm_conf",b"inner_dm_conf","like_conf",b"like_conf","lock_screen_conf",b"lock_screen_conf","next_conf",b"next_conf","outer_dm_conf",b"outer_dm_conf","playback_mode_conf",b"playback_mode_conf","playback_rate_conf",b"playback_rate_conf","playback_speed_conf",b"playback_speed_conf","recommend_conf",b"recommend_conf","scale_mode_conf",b"scale_mode_conf","screen_shot_conf",b"screen_shot_conf","selections_conf",b"selections_conf","shake_conf",b"shake_conf","share_conf",b"share_conf","small_window_conf",b"small_window_conf","subtitle_conf",b"subtitle_conf","time_up_conf",b"time_up_conf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_play_conf",b"background_play_conf","cast_conf",b"cast_conf","coin_conf",b"coin_conf","color_filter_conf",b"color_filter_conf","definition_conf",b"definition_conf","dislike_conf",b"dislike_conf","dolby_conf",b"dolby_conf","edit_dm_conf",b"edit_dm_conf","elec_conf",b"elec_conf","feedback_conf",b"feedback_conf","flip_conf",b"flip_conf","innerDmDisable",b"innerDmDisable","inner_dm_conf",b"inner_dm_conf","like_conf",b"like_conf","lock_screen_conf",b"lock_screen_conf","next_conf",b"next_conf","outer_dm_conf",b"outer_dm_conf","playback_mode_conf",b"playback_mode_conf","playback_rate_conf",b"playback_rate_conf","playback_speed_conf",b"playback_speed_conf","recommend_conf",b"recommend_conf","scale_mode_conf",b"scale_mode_conf","screen_shot_conf",b"screen_shot_conf","selections_conf",b"selections_conf","shake_conf",b"shake_conf","share_conf",b"share_conf","small_window_conf",b"small_window_conf","subtitle_conf",b"subtitle_conf","time_up_conf",b"time_up_conf"]) -> None: ...
global___PlayAbilityConf = PlayAbilityConf

class PlayArcConf(google.protobuf.message.Message):
    """播放控件稿件配置"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BACKGROUND_PLAY_CONF_FIELD_NUMBER: builtins.int
    FLIP_CONF_FIELD_NUMBER: builtins.int
    CAST_CONF_FIELD_NUMBER: builtins.int
    FEEDBACK_CONF_FIELD_NUMBER: builtins.int
    SUBTITLE_CONF_FIELD_NUMBER: builtins.int
    PLAYBACK_RATE_CONF_FIELD_NUMBER: builtins.int
    TIME_UP_CONF_FIELD_NUMBER: builtins.int
    PLAYBACK_MODE_CONF_FIELD_NUMBER: builtins.int
    SCALE_MODE_CONF_FIELD_NUMBER: builtins.int
    LIKE_CONF_FIELD_NUMBER: builtins.int
    DISLIKE_CONF_FIELD_NUMBER: builtins.int
    COIN_CONF_FIELD_NUMBER: builtins.int
    ELEC_CONF_FIELD_NUMBER: builtins.int
    SHARE_CONF_FIELD_NUMBER: builtins.int
    SCREEN_SHOT_CONF_FIELD_NUMBER: builtins.int
    LOCK_SCREEN_CONF_FIELD_NUMBER: builtins.int
    RECOMMEND_CONF_FIELD_NUMBER: builtins.int
    PLAYBACK_SPEED_CONF_FIELD_NUMBER: builtins.int
    DEFINITION_CONF_FIELD_NUMBER: builtins.int
    SELECTIONS_CONF_FIELD_NUMBER: builtins.int
    NEXT_CONF_FIELD_NUMBER: builtins.int
    EDIT_DM_CONF_FIELD_NUMBER: builtins.int
    SMALL_WINDOW_CONF_FIELD_NUMBER: builtins.int
    SHAKE_CONF_FIELD_NUMBER: builtins.int
    OUTER_DM_CONF_FIELD_NUMBER: builtins.int
    INNER_DM_CONF_FIELD_NUMBER: builtins.int
    PANORAMA_CONF_FIELD_NUMBER: builtins.int
    DOLBY_CONF_FIELD_NUMBER: builtins.int
    SCREEN_RECORDING_CONF_FIELD_NUMBER: builtins.int
    COLOR_FILTER_CONF_FIELD_NUMBER: builtins.int
    @property
    def background_play_conf(self) -> global___ArcConf:
        """后台播放"""
        pass
    @property
    def flip_conf(self) -> global___ArcConf:
        """镜像反转"""
        pass
    @property
    def cast_conf(self) -> global___ArcConf:
        """投屏"""
        pass
    @property
    def feedback_conf(self) -> global___ArcConf:
        """反馈"""
        pass
    @property
    def subtitle_conf(self) -> global___ArcConf:
        """字幕"""
        pass
    @property
    def playback_rate_conf(self) -> global___ArcConf:
        """播放速度"""
        pass
    @property
    def time_up_conf(self) -> global___ArcConf:
        """定时停止"""
        pass
    @property
    def playback_mode_conf(self) -> global___ArcConf:
        """播放方式"""
        pass
    @property
    def scale_mode_conf(self) -> global___ArcConf:
        """画面尺寸"""
        pass
    @property
    def like_conf(self) -> global___ArcConf:
        """赞"""
        pass
    @property
    def dislike_conf(self) -> global___ArcConf:
        """踩"""
        pass
    @property
    def coin_conf(self) -> global___ArcConf:
        """投币"""
        pass
    @property
    def elec_conf(self) -> global___ArcConf:
        """充电"""
        pass
    @property
    def share_conf(self) -> global___ArcConf:
        """分享"""
        pass
    @property
    def screen_shot_conf(self) -> global___ArcConf:
        """截图"""
        pass
    @property
    def lock_screen_conf(self) -> global___ArcConf:
        """锁定"""
        pass
    @property
    def recommend_conf(self) -> global___ArcConf:
        """相关推荐"""
        pass
    @property
    def playback_speed_conf(self) -> global___ArcConf:
        """播放速度"""
        pass
    @property
    def definition_conf(self) -> global___ArcConf:
        """清晰度"""
        pass
    @property
    def selections_conf(self) -> global___ArcConf:
        """选集"""
        pass
    @property
    def next_conf(self) -> global___ArcConf:
        """下一集"""
        pass
    @property
    def edit_dm_conf(self) -> global___ArcConf:
        """编辑弹幕"""
        pass
    @property
    def small_window_conf(self) -> global___ArcConf:
        """小窗"""
        pass
    @property
    def shake_conf(self) -> global___ArcConf:
        """震动"""
        pass
    @property
    def outer_dm_conf(self) -> global___ArcConf:
        """外层面板弹幕设置"""
        pass
    @property
    def inner_dm_conf(self) -> global___ArcConf:
        """三点内弹幕设置"""
        pass
    @property
    def panorama_conf(self) -> global___ArcConf:
        """一起看入口"""
        pass
    @property
    def dolby_conf(self) -> global___ArcConf:
        """杜比音效"""
        pass
    @property
    def screen_recording_conf(self) -> global___ArcConf:
        """"""
        pass
    @property
    def color_filter_conf(self) -> global___ArcConf:
        """"""
        pass
    def __init__(self,
        *,
        background_play_conf: typing.Optional[global___ArcConf] = ...,
        flip_conf: typing.Optional[global___ArcConf] = ...,
        cast_conf: typing.Optional[global___ArcConf] = ...,
        feedback_conf: typing.Optional[global___ArcConf] = ...,
        subtitle_conf: typing.Optional[global___ArcConf] = ...,
        playback_rate_conf: typing.Optional[global___ArcConf] = ...,
        time_up_conf: typing.Optional[global___ArcConf] = ...,
        playback_mode_conf: typing.Optional[global___ArcConf] = ...,
        scale_mode_conf: typing.Optional[global___ArcConf] = ...,
        like_conf: typing.Optional[global___ArcConf] = ...,
        dislike_conf: typing.Optional[global___ArcConf] = ...,
        coin_conf: typing.Optional[global___ArcConf] = ...,
        elec_conf: typing.Optional[global___ArcConf] = ...,
        share_conf: typing.Optional[global___ArcConf] = ...,
        screen_shot_conf: typing.Optional[global___ArcConf] = ...,
        lock_screen_conf: typing.Optional[global___ArcConf] = ...,
        recommend_conf: typing.Optional[global___ArcConf] = ...,
        playback_speed_conf: typing.Optional[global___ArcConf] = ...,
        definition_conf: typing.Optional[global___ArcConf] = ...,
        selections_conf: typing.Optional[global___ArcConf] = ...,
        next_conf: typing.Optional[global___ArcConf] = ...,
        edit_dm_conf: typing.Optional[global___ArcConf] = ...,
        small_window_conf: typing.Optional[global___ArcConf] = ...,
        shake_conf: typing.Optional[global___ArcConf] = ...,
        outer_dm_conf: typing.Optional[global___ArcConf] = ...,
        inner_dm_conf: typing.Optional[global___ArcConf] = ...,
        panorama_conf: typing.Optional[global___ArcConf] = ...,
        dolby_conf: typing.Optional[global___ArcConf] = ...,
        screen_recording_conf: typing.Optional[global___ArcConf] = ...,
        color_filter_conf: typing.Optional[global___ArcConf] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["background_play_conf",b"background_play_conf","cast_conf",b"cast_conf","coin_conf",b"coin_conf","color_filter_conf",b"color_filter_conf","definition_conf",b"definition_conf","dislike_conf",b"dislike_conf","dolby_conf",b"dolby_conf","edit_dm_conf",b"edit_dm_conf","elec_conf",b"elec_conf","feedback_conf",b"feedback_conf","flip_conf",b"flip_conf","inner_dm_conf",b"inner_dm_conf","like_conf",b"like_conf","lock_screen_conf",b"lock_screen_conf","next_conf",b"next_conf","outer_dm_conf",b"outer_dm_conf","panorama_conf",b"panorama_conf","playback_mode_conf",b"playback_mode_conf","playback_rate_conf",b"playback_rate_conf","playback_speed_conf",b"playback_speed_conf","recommend_conf",b"recommend_conf","scale_mode_conf",b"scale_mode_conf","screen_recording_conf",b"screen_recording_conf","screen_shot_conf",b"screen_shot_conf","selections_conf",b"selections_conf","shake_conf",b"shake_conf","share_conf",b"share_conf","small_window_conf",b"small_window_conf","subtitle_conf",b"subtitle_conf","time_up_conf",b"time_up_conf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_play_conf",b"background_play_conf","cast_conf",b"cast_conf","coin_conf",b"coin_conf","color_filter_conf",b"color_filter_conf","definition_conf",b"definition_conf","dislike_conf",b"dislike_conf","dolby_conf",b"dolby_conf","edit_dm_conf",b"edit_dm_conf","elec_conf",b"elec_conf","feedback_conf",b"feedback_conf","flip_conf",b"flip_conf","inner_dm_conf",b"inner_dm_conf","like_conf",b"like_conf","lock_screen_conf",b"lock_screen_conf","next_conf",b"next_conf","outer_dm_conf",b"outer_dm_conf","panorama_conf",b"panorama_conf","playback_mode_conf",b"playback_mode_conf","playback_rate_conf",b"playback_rate_conf","playback_speed_conf",b"playback_speed_conf","recommend_conf",b"recommend_conf","scale_mode_conf",b"scale_mode_conf","screen_recording_conf",b"screen_recording_conf","screen_shot_conf",b"screen_shot_conf","selections_conf",b"selections_conf","shake_conf",b"shake_conf","share_conf",b"share_conf","small_window_conf",b"small_window_conf","subtitle_conf",b"subtitle_conf","time_up_conf",b"time_up_conf"]) -> None: ...
global___PlayArcConf = PlayArcConf

class PlayConfEditReply(google.protobuf.message.Message):
    """编辑播放界面配置-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___PlayConfEditReply = PlayConfEditReply

class PlayConfEditReq(google.protobuf.message.Message):
    """编辑播放界面配置-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PLAY_CONF_FIELD_NUMBER: builtins.int
    @property
    def play_conf(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PlayConfState]:
        """播放界面配置"""
        pass
    def __init__(self,
        *,
        play_conf: typing.Optional[typing.Iterable[global___PlayConfState]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["play_conf",b"play_conf"]) -> None: ...
global___PlayConfEditReq = PlayConfEditReq

class PlayConfReply(google.protobuf.message.Message):
    """获取播放界面配置-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PLAY_CONF_FIELD_NUMBER: builtins.int
    @property
    def play_conf(self) -> global___PlayAbilityConf:
        """播放控件用户自定义配置"""
        pass
    def __init__(self,
        *,
        play_conf: typing.Optional[global___PlayAbilityConf] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["play_conf",b"play_conf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["play_conf",b"play_conf"]) -> None: ...
global___PlayConfReply = PlayConfReply

class PlayConfReq(google.protobuf.message.Message):
    """获取播放界面配置-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___PlayConfReq = PlayConfReq

class PlayConfState(google.protobuf.message.Message):
    """播放界面配置"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONF_TYPE_FIELD_NUMBER: builtins.int
    SHOW_FIELD_NUMBER: builtins.int
    FIELD_VALUE_FIELD_NUMBER: builtins.int
    CONF_VALUE_FIELD_NUMBER: builtins.int
    conf_type: global___ConfType.ValueType
    """设置类型"""

    show: builtins.bool
    """是否隐藏"""

    @property
    def field_value(self) -> global___FieldValue:
        """配置字段值"""
        pass
    @property
    def conf_value(self) -> global___ConfValue:
        """"""
        pass
    def __init__(self,
        *,
        conf_type: global___ConfType.ValueType = ...,
        show: builtins.bool = ...,
        field_value: typing.Optional[global___FieldValue] = ...,
        conf_value: typing.Optional[global___ConfValue] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conf_value",b"conf_value","field_value",b"field_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conf_type",b"conf_type","conf_value",b"conf_value","field_value",b"field_value","show",b"show"]) -> None: ...
global___PlayConfState = PlayConfState

class PlayURLReply(google.protobuf.message.Message):
    """视频地址-回复"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    QUALITY_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    TIMELENGTH_FIELD_NUMBER: builtins.int
    VIDEO_CODECID_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    VIDEO_PROJECT_FIELD_NUMBER: builtins.int
    DURL_FIELD_NUMBER: builtins.int
    DASH_FIELD_NUMBER: builtins.int
    NO_REXCODE_FIELD_NUMBER: builtins.int
    UPGRADE_LIMIT_FIELD_NUMBER: builtins.int
    SUPPORT_FORMATS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    quality: builtins.int
    """清晰的"""

    format: typing.Text
    """格式"""

    timelength: builtins.int
    """总时长(单位为ms)"""

    video_codecid: builtins.int
    """编码id"""

    fnver: builtins.int
    """视频流版本"""

    fnval: builtins.int
    """视频流格式"""

    video_project: builtins.bool
    """是否支持投影"""

    @property
    def durl(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResponseUrl]:
        """分段视频流列表"""
        pass
    @property
    def dash(self) -> global___ResponseDash:
        """dash数据"""
        pass
    no_rexcode: builtins.int
    """是否非全二压"""

    @property
    def upgrade_limit(self) -> global___UpgradeLimit:
        """互动视频升级提示"""
        pass
    @property
    def support_formats(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FormatDescription]:
        """清晰度描述列表"""
        pass
    type: global___VideoType.ValueType
    """视频格式"""

    def __init__(self,
        *,
        quality: builtins.int = ...,
        format: typing.Text = ...,
        timelength: builtins.int = ...,
        video_codecid: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        video_project: builtins.bool = ...,
        durl: typing.Optional[typing.Iterable[global___ResponseUrl]] = ...,
        dash: typing.Optional[global___ResponseDash] = ...,
        no_rexcode: builtins.int = ...,
        upgrade_limit: typing.Optional[global___UpgradeLimit] = ...,
        support_formats: typing.Optional[typing.Iterable[global___FormatDescription]] = ...,
        type: global___VideoType.ValueType = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dash",b"dash","upgrade_limit",b"upgrade_limit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dash",b"dash","durl",b"durl","fnval",b"fnval","fnver",b"fnver","format",b"format","no_rexcode",b"no_rexcode","quality",b"quality","support_formats",b"support_formats","timelength",b"timelength","type",b"type","upgrade_limit",b"upgrade_limit","video_codecid",b"video_codecid","video_project",b"video_project"]) -> None: ...
global___PlayURLReply = PlayURLReply

class PlayURLReq(google.protobuf.message.Message):
    """视频地址-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""

    cid: builtins.int
    """视频cid"""

    qn: builtins.int
    """清晰度"""

    fnver: builtins.int
    """视频流版本"""

    fnval: builtins.int
    """视频流格式"""

    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """

    force_host: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """

    fourk: builtins.bool
    """是否4K"""

    spmid: typing.Text
    """当前页spm"""

    from_spmid: typing.Text
    """上一页spm"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: typing.Text = ...,
        from_spmid: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","cid",b"cid","download",b"download","fnval",b"fnval","fnver",b"fnver","force_host",b"force_host","fourk",b"fourk","from_spmid",b"from_spmid","qn",b"qn","spmid",b"spmid"]) -> None: ...
global___PlayURLReq = PlayURLReq

class PlayViewReply(google.protobuf.message.Message):
    """播放页信息-回复"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VIDEO_INFO_FIELD_NUMBER: builtins.int
    PLAY_CONF_FIELD_NUMBER: builtins.int
    UPGRADE_LIMIT_FIELD_NUMBER: builtins.int
    CHRONOS_FIELD_NUMBER: builtins.int
    PLAY_ARC_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    AB_FIELD_NUMBER: builtins.int
    @property
    def video_info(self) -> global___VideoInfo:
        """视频流信息"""
        pass
    @property
    def play_conf(self) -> global___PlayAbilityConf:
        """播放控件用户自定义配置"""
        pass
    @property
    def upgrade_limit(self) -> global___UpgradeLimit:
        """互动视频升级提示"""
        pass
    @property
    def chronos(self) -> global___Chronos:
        """Chronos灰度管理"""
        pass
    @property
    def play_arc(self) -> global___PlayArcConf:
        """播放控件稿件配置"""
        pass
    @property
    def event(self) -> global___Event:
        """事件"""
        pass
    @property
    def ab(self) -> global___AB:
        """"""
        pass
    def __init__(self,
        *,
        video_info: typing.Optional[global___VideoInfo] = ...,
        play_conf: typing.Optional[global___PlayAbilityConf] = ...,
        upgrade_limit: typing.Optional[global___UpgradeLimit] = ...,
        chronos: typing.Optional[global___Chronos] = ...,
        play_arc: typing.Optional[global___PlayArcConf] = ...,
        event: typing.Optional[global___Event] = ...,
        ab: typing.Optional[global___AB] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ab",b"ab","chronos",b"chronos","event",b"event","play_arc",b"play_arc","play_conf",b"play_conf","upgrade_limit",b"upgrade_limit","video_info",b"video_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ab",b"ab","chronos",b"chronos","event",b"event","play_arc",b"play_arc","play_conf",b"play_conf","upgrade_limit",b"upgrade_limit","video_info",b"video_info"]) -> None: ...
global___PlayViewReply = PlayViewReply

class PlayViewReq(google.protobuf.message.Message):
    """播放页信息-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    PREFER_CODEC_TYPE_FIELD_NUMBER: builtins.int
    BUSINESS_FIELD_NUMBER: builtins.int
    VOICE_BALANCE_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""

    cid: builtins.int
    """视频cid"""

    qn: builtins.int
    """清晰度"""

    fnver: builtins.int
    """视频流版本"""

    fnval: builtins.int
    """视频流格式"""

    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """

    force_host: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """

    fourk: builtins.bool
    """是否4K"""

    spmid: typing.Text
    """当前页spm"""

    from_spmid: typing.Text
    """上一页spm"""

    teenagers_mode: builtins.int
    """青少年模式"""

    prefer_codec_type: global___CodeType.ValueType
    """编码"""

    business: global___Business.ValueType
    """业务类型"""

    voice_balance: builtins.int
    """"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: typing.Text = ...,
        from_spmid: typing.Text = ...,
        teenagers_mode: builtins.int = ...,
        prefer_codec_type: global___CodeType.ValueType = ...,
        business: global___Business.ValueType = ...,
        voice_balance: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","business",b"business","cid",b"cid","download",b"download","fnval",b"fnval","fnver",b"fnver","force_host",b"force_host","fourk",b"fourk","from_spmid",b"from_spmid","prefer_codec_type",b"prefer_codec_type","qn",b"qn","spmid",b"spmid","teenagers_mode",b"teenagers_mode","voice_balance",b"voice_balance"]) -> None: ...
global___PlayViewReq = PlayViewReq

class ProjectReply(google.protobuf.message.Message):
    """投屏地址-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROJECT_FIELD_NUMBER: builtins.int
    @property
    def project(self) -> global___PlayURLReply: ...
    def __init__(self,
        *,
        project: typing.Optional[global___PlayURLReply] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["project",b"project"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["project",b"project"]) -> None: ...
global___ProjectReply = ProjectReply

class ProjectReq(google.protobuf.message.Message):
    """投屏地址-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""

    cid: builtins.int
    """视频cid"""

    qn: builtins.int
    """清晰度"""

    fnver: builtins.int
    """视频流版本"""

    fnval: builtins.int
    """视频流格式"""

    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """

    force_host: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """

    fourk: builtins.bool
    """是否4K"""

    spmid: typing.Text
    """当前页spm"""

    from_spmid: typing.Text
    """上一页spm"""

    protocol: builtins.int
    """使用协议
    0:默认乐播 1:自建协议 2:云投屏 3:airplay
    """

    device_type: builtins.int
    """投屏设备
    0:默认其他 1:OTT设备
    """

    def __init__(self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: typing.Text = ...,
        from_spmid: typing.Text = ...,
        protocol: builtins.int = ...,
        device_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","cid",b"cid","device_type",b"device_type","download",b"download","fnval",b"fnval","fnver",b"fnver","force_host",b"force_host","fourk",b"fourk","from_spmid",b"from_spmid","protocol",b"protocol","qn",b"qn","spmid",b"spmid"]) -> None: ...
global___ProjectReq = ProjectReq

class ResponseDash(google.protobuf.message.Message):
    """dash数据"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VIDEO_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    @property
    def video(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DashItem]:
        """dash视频流"""
        pass
    @property
    def audio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DashItem]:
        """dash伴音流"""
        pass
    def __init__(self,
        *,
        video: typing.Optional[typing.Iterable[global___DashItem]] = ...,
        audio: typing.Optional[typing.Iterable[global___DashItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio",b"audio","video",b"video"]) -> None: ...
global___ResponseDash = ResponseDash

class ResponseUrl(google.protobuf.message.Message):
    """分段流条目"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ORDER_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    order: builtins.int
    """分段序号"""

    length: builtins.int
    """分段时长"""

    size: builtins.int
    """分段大小"""

    url: typing.Text
    """主线流"""

    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """备用流"""
        pass
    md5: typing.Text
    """md5"""

    def __init__(self,
        *,
        order: builtins.int = ...,
        length: builtins.int = ...,
        size: builtins.int = ...,
        url: typing.Text = ...,
        backup_url: typing.Optional[typing.Iterable[typing.Text]] = ...,
        md5: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_url",b"backup_url","length",b"length","md5",b"md5","order",b"order","size",b"size","url",b"url"]) -> None: ...
global___ResponseUrl = ResponseUrl

class SegmentVideo(google.protobuf.message.Message):
    """分段视频流"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SEGMENT_FIELD_NUMBER: builtins.int
    @property
    def segment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResponseUrl]:
        """分段视频流列表"""
        pass
    def __init__(self,
        *,
        segment: typing.Optional[typing.Iterable[global___ResponseUrl]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["segment",b"segment"]) -> None: ...
global___SegmentVideo = SegmentVideo

class Shake(google.protobuf.message.Message):
    """震动"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FILE_FIELD_NUMBER: builtins.int
    file: typing.Text
    """文件地址"""

    def __init__(self,
        *,
        file: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file",b"file"]) -> None: ...
global___Shake = Shake

class Stream(google.protobuf.message.Message):
    """视频流信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STREAM_INFO_FIELD_NUMBER: builtins.int
    DASH_VIDEO_FIELD_NUMBER: builtins.int
    SEGMENT_VIDEO_FIELD_NUMBER: builtins.int
    @property
    def stream_info(self) -> global___StreamInfo:
        """元数据"""
        pass
    @property
    def dash_video(self) -> global___DashVideo:
        """dash流"""
        pass
    @property
    def segment_video(self) -> global___SegmentVideo:
        """分段流"""
        pass
    def __init__(self,
        *,
        stream_info: typing.Optional[global___StreamInfo] = ...,
        dash_video: typing.Optional[global___DashVideo] = ...,
        segment_video: typing.Optional[global___SegmentVideo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content",b"content","dash_video",b"dash_video","segment_video",b"segment_video","stream_info",b"stream_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","dash_video",b"dash_video","segment_video",b"segment_video","stream_info",b"stream_info"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["content",b"content"]) -> typing.Optional[typing_extensions.Literal["dash_video","segment_video"]]: ...
global___Stream = Stream

class StreamInfo(google.protobuf.message.Message):
    """流媒体元数据"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    QUALITY_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ERR_CODE_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    NEED_VIP_FIELD_NUMBER: builtins.int
    NEED_LOGIN_FIELD_NUMBER: builtins.int
    INTACT_FIELD_NUMBER: builtins.int
    NO_REXCODE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    NEW_DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_DESC_FIELD_NUMBER: builtins.int
    SUPERSCRIPT_FIELD_NUMBER: builtins.int
    quality: builtins.int
    """清晰度"""

    format: typing.Text
    """格式"""

    description: typing.Text
    """格式描述"""

    err_code: builtins.int
    """错误码"""

    @property
    def limit(self) -> global___StreamLimit:
        """不满足条件信息"""
        pass
    need_vip: builtins.bool
    """是否需要vip"""

    need_login: builtins.bool
    """是否需要登录"""

    intact: builtins.bool
    """是否完整"""

    no_rexcode: builtins.bool
    """是否非全二压"""

    attribute: builtins.int
    """清晰度属性位"""

    new_description: typing.Text
    """新版格式描述"""

    display_desc: typing.Text
    """格式文字"""

    superscript: typing.Text
    """新版格式描述备注"""

    def __init__(self,
        *,
        quality: builtins.int = ...,
        format: typing.Text = ...,
        description: typing.Text = ...,
        err_code: builtins.int = ...,
        limit: typing.Optional[global___StreamLimit] = ...,
        need_vip: builtins.bool = ...,
        need_login: builtins.bool = ...,
        intact: builtins.bool = ...,
        no_rexcode: builtins.bool = ...,
        attribute: builtins.int = ...,
        new_description: typing.Text = ...,
        display_desc: typing.Text = ...,
        superscript: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["limit",b"limit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute",b"attribute","description",b"description","display_desc",b"display_desc","err_code",b"err_code","format",b"format","intact",b"intact","limit",b"limit","need_login",b"need_login","need_vip",b"need_vip","new_description",b"new_description","no_rexcode",b"no_rexcode","quality",b"quality","superscript",b"superscript"]) -> None: ...
global___StreamInfo = StreamInfo

class StreamLimit(google.protobuf.message.Message):
    """清晰度不满足条件信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    uri: typing.Text
    """跳转地址"""

    msg: typing.Text
    """提示信息"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        uri: typing.Text = ...,
        msg: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg",b"msg","title",b"title","uri",b"uri"]) -> None: ...
global___StreamLimit = StreamLimit

class UpgradeButton(google.protobuf.message.Message):
    """互动视频升级按钮信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    link: typing.Text
    """链接"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        link: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["link",b"link","title",b"title"]) -> None: ...
global___UpgradeButton = UpgradeButton

class UpgradeLimit(google.protobuf.message.Message):
    """互动视频升级提示"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    code: builtins.int
    """错误码"""

    message: typing.Text
    """错误信息"""

    image: typing.Text
    """图片url"""

    @property
    def button(self) -> global___UpgradeButton:
        """按钮信息"""
        pass
    def __init__(self,
        *,
        code: builtins.int = ...,
        message: typing.Text = ...,
        image: typing.Text = ...,
        button: typing.Optional[global___UpgradeButton] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button",b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button",b"button","code",b"code","image",b"image","message",b"message"]) -> None: ...
global___UpgradeLimit = UpgradeLimit

class VideoInfo(google.protobuf.message.Message):
    """视频url信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    QUALITY_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    TIMELENGTH_FIELD_NUMBER: builtins.int
    VIDEO_CODECID_FIELD_NUMBER: builtins.int
    STREAM_LIST_FIELD_NUMBER: builtins.int
    DASH_AUDIO_FIELD_NUMBER: builtins.int
    DOLBY_FIELD_NUMBER: builtins.int
    VOLUME_FIELD_NUMBER: builtins.int
    quality: builtins.int
    """视频清晰度"""

    format: typing.Text
    """视频格式"""

    timelength: builtins.int
    """视频时长"""

    video_codecid: builtins.int
    """视频编码id"""

    @property
    def stream_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Stream]:
        """视频流"""
        pass
    @property
    def dash_audio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DashItem]:
        """伴音流"""
        pass
    @property
    def dolby(self) -> global___DolbyItem:
        """杜比伴音流"""
        pass
    @property
    def volume(self) -> global___VolumeInfo:
        """"""
        pass
    def __init__(self,
        *,
        quality: builtins.int = ...,
        format: typing.Text = ...,
        timelength: builtins.int = ...,
        video_codecid: builtins.int = ...,
        stream_list: typing.Optional[typing.Iterable[global___Stream]] = ...,
        dash_audio: typing.Optional[typing.Iterable[global___DashItem]] = ...,
        dolby: typing.Optional[global___DolbyItem] = ...,
        volume: typing.Optional[global___VolumeInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dolby",b"dolby","volume",b"volume"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dash_audio",b"dash_audio","dolby",b"dolby","format",b"format","quality",b"quality","stream_list",b"stream_list","timelength",b"timelength","video_codecid",b"video_codecid","volume",b"volume"]) -> None: ...
global___VideoInfo = VideoInfo

class VolumeInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MEASURED_I_FIELD_NUMBER: builtins.int
    MEASURED_LRA_FIELD_NUMBER: builtins.int
    MEASURED_TP_FIELD_NUMBER: builtins.int
    MEASURED_THRESHOLD_FIELD_NUMBER: builtins.int
    TARGET_OFFSET_FIELD_NUMBER: builtins.int
    TARGET_I_FIELD_NUMBER: builtins.int
    TARGET_TP_FIELD_NUMBER: builtins.int
    measured_i: builtins.float
    """"""

    measured_lra: builtins.float
    """"""

    measured_tp: builtins.float
    """"""

    measured_threshold: builtins.float
    """"""

    target_offset: builtins.float
    """"""

    target_i: builtins.float
    """"""

    target_tp: builtins.float
    """"""

    def __init__(self,
        *,
        measured_i: builtins.float = ...,
        measured_lra: builtins.float = ...,
        measured_tp: builtins.float = ...,
        measured_threshold: builtins.float = ...,
        target_offset: builtins.float = ...,
        target_i: builtins.float = ...,
        target_tp: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["measured_i",b"measured_i","measured_lra",b"measured_lra","measured_threshold",b"measured_threshold","measured_tp",b"measured_tp","target_i",b"target_i","target_offset",b"target_offset","target_tp",b"target_tp"]) -> None: ...
global___VolumeInfo = VolumeInfo



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DT:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _DTEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DT.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Unknown: _DT.ValueType  # 0
    """未知"""

    Phone: _DT.ValueType  # 1
    """手机端"""

    Pad: _DT.ValueType  # 2
    """ipad端"""

    PC: _DT.ValueType  # 3
    """web端"""

    TV: _DT.ValueType  # 4
    """TV端"""

    Car: _DT.ValueType  # 5
    """"""

    Iot: _DT.ValueType  # 6
    """"""

    AndPad: _DT.ValueType  # 7
    """apad端"""

class DT(_DT, metaclass=_DTEnumTypeWrapper):
    """设备标识代码"""
    pass

Unknown: DT.ValueType  # 0
"""未知"""

Phone: DT.ValueType  # 1
"""手机端"""

Pad: DT.ValueType  # 2
"""ipad端"""

PC: DT.ValueType  # 3
"""web端"""

TV: DT.ValueType  # 4
"""TV端"""

Car: DT.ValueType  # 5
""""""

Iot: DT.ValueType  # 6
""""""

AndPad: DT.ValueType  # 7
"""apad端"""

global___DT = DT


class _HistorySource:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _HistorySourceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HistorySource.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    history_VALUE: _HistorySource.ValueType  # 0
    """主站历史记录页"""

    shopping_VALUE: _HistorySource.ValueType  # 1
    """会员购浏览记录"""

class HistorySource(_HistorySource, metaclass=_HistorySourceEnumTypeWrapper):
    """搜索历史记录来源"""
    pass

history_VALUE: HistorySource.ValueType  # 0
"""主站历史记录页"""

shopping_VALUE: HistorySource.ValueType  # 1
"""会员购浏览记录"""

global___HistorySource = HistorySource


class CardArticle(google.protobuf.message.Message):
    """专栏卡片"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COVERS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    DISPLAYATTENTION_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    @property
    def covers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """封面url"""
        pass
    name: typing.Text
    """UP主昵称"""

    mid: builtins.int
    """UP主mid"""

    displayAttention: builtins.bool
    """是否展示关注按钮"""

    badge: typing.Text
    """角标"""

    @property
    def relation(self) -> global___Relation:
        """关系信息"""
        pass
    def __init__(self,
        *,
        covers: typing.Optional[typing.Iterable[typing.Text]] = ...,
        name: typing.Text = ...,
        mid: builtins.int = ...,
        displayAttention: builtins.bool = ...,
        badge: typing.Text = ...,
        relation: typing.Optional[global___Relation] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relation",b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge",b"badge","covers",b"covers","displayAttention",b"displayAttention","mid",b"mid","name",b"name","relation",b"relation"]) -> None: ...
global___CardArticle = CardArticle

class CardCheese(google.protobuf.message.Message):
    """课程卡片"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COVER_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    cover: typing.Text
    """封面url"""

    progress: builtins.int
    """观看进度"""

    duration: builtins.int
    """总计时长"""

    subtitle: typing.Text
    """单集标题"""

    def __init__(self,
        *,
        cover: typing.Text = ...,
        progress: builtins.int = ...,
        duration: builtins.int = ...,
        subtitle: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover",b"cover","duration",b"duration","progress",b"progress","subtitle",b"subtitle"]) -> None: ...
global___CardCheese = CardCheese

class CardLive(google.protobuf.message.Message):
    """直播卡片"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COVER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    STSTUS_FIELD_NUMBER: builtins.int
    DISPLAY_ATTENTION_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    cover: typing.Text
    """封面url"""

    name: typing.Text
    """主播昵称"""

    mid: builtins.int
    """主播mid"""

    tag: typing.Text
    """直播分区名"""

    ststus: builtins.int
    """直播状态"""

    display_attention: builtins.bool
    """是否展示关注按钮"""

    @property
    def relation(self) -> global___Relation:
        """关系信息"""
        pass
    def __init__(self,
        *,
        cover: typing.Text = ...,
        name: typing.Text = ...,
        mid: builtins.int = ...,
        tag: typing.Text = ...,
        ststus: builtins.int = ...,
        display_attention: builtins.bool = ...,
        relation: typing.Optional[global___Relation] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relation",b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover",b"cover","display_attention",b"display_attention","mid",b"mid","name",b"name","relation",b"relation","ststus",b"ststus","tag",b"tag"]) -> None: ...
global___CardLive = CardLive

class CardOGV(google.protobuf.message.Message):
    """pgc稿件卡片"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COVER_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    cover: typing.Text
    """封面url"""

    progress: builtins.int
    """观看进度"""

    duration: builtins.int
    """总计时长"""

    subtitle: typing.Text
    """单集标题"""

    def __init__(self,
        *,
        cover: typing.Text = ...,
        progress: builtins.int = ...,
        duration: builtins.int = ...,
        subtitle: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover",b"cover","duration",b"duration","progress",b"progress","subtitle",b"subtitle"]) -> None: ...
global___CardOGV = CardOGV

class CardUGC(google.protobuf.message.Message):
    """ugc稿件卡片"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COVER_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    DISPLAY_ATTENTION_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    SHORT_LINK_FIELD_NUMBER: builtins.int
    SHARE_SUBTITLE_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    cover: typing.Text
    """封面url"""

    progress: builtins.int
    """观看进度"""

    duration: builtins.int
    """视频长度"""

    name: typing.Text
    """UP主昵称"""

    mid: builtins.int
    """UP主mid"""

    display_attention: builtins.bool
    """是否展示关注按钮"""

    cid: builtins.int
    """历史观看视频cid"""

    page: builtins.int
    """历史观看视频分P"""

    subtitle: typing.Text
    """历史观看视频分P的标题"""

    @property
    def relation(self) -> global___Relation:
        """关系信息"""
        pass
    bvid: typing.Text
    """稿件bvid"""

    videos: builtins.int
    """总分P数"""

    short_link: typing.Text
    """短链接"""

    share_subtitle: typing.Text
    """分享副标题"""

    view: builtins.int
    """播放数"""

    state: builtins.int
    """"""

    def __init__(self,
        *,
        cover: typing.Text = ...,
        progress: builtins.int = ...,
        duration: builtins.int = ...,
        name: typing.Text = ...,
        mid: builtins.int = ...,
        display_attention: builtins.bool = ...,
        cid: builtins.int = ...,
        page: builtins.int = ...,
        subtitle: typing.Text = ...,
        relation: typing.Optional[global___Relation] = ...,
        bvid: typing.Text = ...,
        videos: builtins.int = ...,
        short_link: typing.Text = ...,
        share_subtitle: typing.Text = ...,
        view: builtins.int = ...,
        state: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relation",b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bvid",b"bvid","cid",b"cid","cover",b"cover","display_attention",b"display_attention","duration",b"duration","mid",b"mid","name",b"name","page",b"page","progress",b"progress","relation",b"relation","share_subtitle",b"share_subtitle","short_link",b"short_link","state",b"state","subtitle",b"subtitle","videos",b"videos","view",b"view"]) -> None: ...
global___CardUGC = CardUGC

class ClearReq(google.protobuf.message.Message):
    """清空历史记录-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BUSINESS_FIELD_NUMBER: builtins.int
    business: typing.Text
    """业务类型
    archive:视频 live:直播 article:专栏 goods:商品 show:展演
    """

    def __init__(self,
        *,
        business: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["business",b"business"]) -> None: ...
global___ClearReq = ClearReq

class Cursor(google.protobuf.message.Message):
    """游标信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MAX_FIELD_NUMBER: builtins.int
    MAXTP_FIELD_NUMBER: builtins.int
    max: builtins.int
    """本页最大值游标值"""

    maxTp: builtins.int
    """本页最大值游标类型"""

    def __init__(self,
        *,
        max: builtins.int = ...,
        maxTp: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max",b"max","maxTp",b"maxTp"]) -> None: ...
global___Cursor = Cursor

class CursorItem(google.protobuf.message.Message):
    """历史记录卡片信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CARD_UGC_FIELD_NUMBER: builtins.int
    CARD_OGV_FIELD_NUMBER: builtins.int
    CARD_ARTICLE_FIELD_NUMBER: builtins.int
    CARD_LIVE_FIELD_NUMBER: builtins.int
    CARD_CHEESE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    VIEWAT_FIELD_NUMBER: builtins.int
    KID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    BUSINESS_FIELD_NUMBER: builtins.int
    TP_FIELD_NUMBER: builtins.int
    DT_FIELD_NUMBER: builtins.int
    HAS_SHARE_FIELD_NUMBER: builtins.int
    @property
    def card_ugc(self) -> global___CardUGC:
        """ugc稿件"""
        pass
    @property
    def card_ogv(self) -> global___CardOGV:
        """pgc稿件"""
        pass
    @property
    def card_article(self) -> global___CardArticle:
        """专栏"""
        pass
    @property
    def card_live(self) -> global___CardLive:
        """直播"""
        pass
    @property
    def card_cheese(self) -> global___CardCheese:
        """课程"""
        pass
    title: typing.Text
    """标题"""

    uri: typing.Text
    """目标uri/url"""

    viewAt: builtins.int
    """观看时间"""

    kid: builtins.int
    """历史记录id"""

    oid: builtins.int
    """业务id"""

    business: typing.Text
    """业务类型
    archive:视频 live:直播 article:专栏 goods:商品 show:展演
    """

    tp: builtins.int
    """业务类型代码"""

    @property
    def dt(self) -> global___DeviceType:
        """设备标识"""
        pass
    has_share: builtins.bool
    """是否有分享按钮"""

    def __init__(self,
        *,
        card_ugc: typing.Optional[global___CardUGC] = ...,
        card_ogv: typing.Optional[global___CardOGV] = ...,
        card_article: typing.Optional[global___CardArticle] = ...,
        card_live: typing.Optional[global___CardLive] = ...,
        card_cheese: typing.Optional[global___CardCheese] = ...,
        title: typing.Text = ...,
        uri: typing.Text = ...,
        viewAt: builtins.int = ...,
        kid: builtins.int = ...,
        oid: builtins.int = ...,
        business: typing.Text = ...,
        tp: builtins.int = ...,
        dt: typing.Optional[global___DeviceType] = ...,
        has_share: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card_article",b"card_article","card_cheese",b"card_cheese","card_item",b"card_item","card_live",b"card_live","card_ogv",b"card_ogv","card_ugc",b"card_ugc","dt",b"dt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business",b"business","card_article",b"card_article","card_cheese",b"card_cheese","card_item",b"card_item","card_live",b"card_live","card_ogv",b"card_ogv","card_ugc",b"card_ugc","dt",b"dt","has_share",b"has_share","kid",b"kid","oid",b"oid","title",b"title","tp",b"tp","uri",b"uri","viewAt",b"viewAt"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["card_item",b"card_item"]) -> typing.Optional[typing_extensions.Literal["card_ugc","card_ogv","card_article","card_live","card_cheese"]]: ...
global___CursorItem = CursorItem

class CursorReply(google.protobuf.message.Message):
    """获取历史记录列表(旧版)-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEMS_FIELD_NUMBER: builtins.int
    TAB_FIELD_NUMBER: builtins.int
    CURSOR_FIELD_NUMBER: builtins.int
    HASMORE_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CursorItem]:
        """卡片内容"""
        pass
    @property
    def tab(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CursorTab]:
        """顶部tab"""
        pass
    @property
    def cursor(self) -> global___Cursor:
        """游标信息"""
        pass
    hasMore: builtins.bool
    """是否未拉取完"""

    def __init__(self,
        *,
        items: typing.Optional[typing.Iterable[global___CursorItem]] = ...,
        tab: typing.Optional[typing.Iterable[global___CursorTab]] = ...,
        cursor: typing.Optional[global___Cursor] = ...,
        hasMore: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor",b"cursor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cursor",b"cursor","hasMore",b"hasMore","items",b"items","tab",b"tab"]) -> None: ...
global___CursorReply = CursorReply

class CursorReq(google.protobuf.message.Message):
    """获取历史记录列表(旧版)-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CURSOR_FIELD_NUMBER: builtins.int
    BUSINESS_FIELD_NUMBER: builtins.int
    PLAYER_PRELOAD_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___Cursor:
        """游标信息"""
        pass
    business: typing.Text
    """业务类型
    all:全部 archive:视频 live:直播 article:专栏
    """

    @property
    def player_preload(self) -> global___PlayerPreloadParams:
        """秒开参数(旧版)"""
        pass
    @property
    def player_args(self) -> bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
        pass
    def __init__(self,
        *,
        cursor: typing.Optional[global___Cursor] = ...,
        business: typing.Text = ...,
        player_preload: typing.Optional[global___PlayerPreloadParams] = ...,
        player_args: typing.Optional[bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor",b"cursor","player_args",b"player_args","player_preload",b"player_preload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business",b"business","cursor",b"cursor","player_args",b"player_args","player_preload",b"player_preload"]) -> None: ...
global___CursorReq = CursorReq

class CursorTab(google.protobuf.message.Message):
    """业务分类表"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BUSINESS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ROUTER_FIELD_NUMBER: builtins.int
    FOCUS_FIELD_NUMBER: builtins.int
    business: typing.Text
    """业务类型"""

    name: typing.Text
    """名称"""

    router: typing.Text
    """路由uri"""

    focus: builtins.bool
    """tab定位"""

    def __init__(self,
        *,
        business: typing.Text = ...,
        name: typing.Text = ...,
        router: typing.Text = ...,
        focus: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["business",b"business","focus",b"focus","name",b"name","router",b"router"]) -> None: ...
global___CursorTab = CursorTab

class CursorV2Reply(google.protobuf.message.Message):
    """获取历史记录列表-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEMS_FIELD_NUMBER: builtins.int
    CURSOR_FIELD_NUMBER: builtins.int
    HASMORE_FIELD_NUMBER: builtins.int
    EMPTY_LINK_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CursorItem]:
        """卡片内容"""
        pass
    @property
    def cursor(self) -> global___Cursor:
        """游标信息"""
        pass
    hasMore: builtins.bool
    """是否未拉取完"""

    empty_link: typing.Text
    """"""

    def __init__(self,
        *,
        items: typing.Optional[typing.Iterable[global___CursorItem]] = ...,
        cursor: typing.Optional[global___Cursor] = ...,
        hasMore: builtins.bool = ...,
        empty_link: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor",b"cursor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cursor",b"cursor","empty_link",b"empty_link","hasMore",b"hasMore","items",b"items"]) -> None: ...
global___CursorV2Reply = CursorV2Reply

class CursorV2Req(google.protobuf.message.Message):
    """获取历史记录列表-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CURSOR_FIELD_NUMBER: builtins.int
    BUSINESS_FIELD_NUMBER: builtins.int
    PLAYER_PRELOAD_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    IS_LOCAL_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___Cursor:
        """游标信息"""
        pass
    business: typing.Text
    """业务类型
    archive:视频 live:直播 article:专栏 goods:商品 show:展演
    """

    @property
    def player_preload(self) -> global___PlayerPreloadParams:
        """秒开参数(旧版)"""
        pass
    @property
    def player_args(self) -> bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
        pass
    is_local: builtins.bool
    """是否选择本机的播放历史"""

    def __init__(self,
        *,
        cursor: typing.Optional[global___Cursor] = ...,
        business: typing.Text = ...,
        player_preload: typing.Optional[global___PlayerPreloadParams] = ...,
        player_args: typing.Optional[bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs] = ...,
        is_local: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor",b"cursor","player_args",b"player_args","player_preload",b"player_preload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business",b"business","cursor",b"cursor","is_local",b"is_local","player_args",b"player_args","player_preload",b"player_preload"]) -> None: ...
global___CursorV2Req = CursorV2Req

class DeleteReq(google.protobuf.message.Message):
    """删除历史记录-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HIS_INFO_FIELD_NUMBER: builtins.int
    @property
    def his_info(self) -> global___HisInfo:
        """历史记录信息"""
        pass
    def __init__(self,
        *,
        his_info: typing.Optional[global___HisInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["his_info",b"his_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["his_info",b"his_info"]) -> None: ...
global___DeleteReq = DeleteReq

class DeviceType(google.protobuf.message.Message):
    """设备类型"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    type: global___DT.ValueType
    """设备标识代码"""

    icon: typing.Text
    """图标url"""

    def __init__(self,
        *,
        type: global___DT.ValueType = ...,
        icon: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon",b"icon","type",b"type"]) -> None: ...
global___DeviceType = DeviceType

class HisInfo(google.protobuf.message.Message):
    """历史记录信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BUSINESS_FIELD_NUMBER: builtins.int
    KID_FIELD_NUMBER: builtins.int
    business: typing.Text
    """业务类型
    archive:视频 live:直播 article:专栏 goods:商品 show:展演
    """

    kid: builtins.int
    """历史记录id"""

    def __init__(self,
        *,
        business: typing.Text = ...,
        kid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["business",b"business","kid",b"kid"]) -> None: ...
global___HisInfo = HisInfo

class HistoryTabReply(google.protobuf.message.Message):
    """获取历史记录tab-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TAB_FIELD_NUMBER: builtins.int
    @property
    def tab(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CursorTab]:
        """tab列表"""
        pass
    def __init__(self,
        *,
        tab: typing.Optional[typing.Iterable[global___CursorTab]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tab",b"tab"]) -> None: ...
global___HistoryTabReply = HistoryTabReply

class HistoryTabReq(google.protobuf.message.Message):
    """获取历史记录tab-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BUSINESS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    business: typing.Text
    """业务类型
    archive:视频 live:直播 article:专栏 goods:商品 show:展演
    """

    source: global___HistorySource.ValueType
    """查询请求来源"""

    keyword: typing.Text
    """搜索关键词"""

    def __init__(self,
        *,
        business: typing.Text = ...,
        source: global___HistorySource.ValueType = ...,
        keyword: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["business",b"business","keyword",b"keyword","source",b"source"]) -> None: ...
global___HistoryTabReq = HistoryTabReq

class LatestHistoryReply(google.protobuf.message.Message):
    """获取最新的历史记录-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEMS_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    RTIME_FIELD_NUMBER: builtins.int
    FLAG_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> global___CursorItem:
        """卡片内容"""
        pass
    scene: typing.Text
    """场景"""

    rtime: builtins.int
    """弹窗停留时间"""

    flag: typing.Text
    """分组的标志(客户端埋点上报)"""

    def __init__(self,
        *,
        items: typing.Optional[global___CursorItem] = ...,
        scene: typing.Text = ...,
        rtime: builtins.int = ...,
        flag: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["items",b"items"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["flag",b"flag","items",b"items","rtime",b"rtime","scene",b"scene"]) -> None: ...
global___LatestHistoryReply = LatestHistoryReply

class LatestHistoryReq(google.protobuf.message.Message):
    """获取最新的历史记录-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BUSINESS_FIELD_NUMBER: builtins.int
    PLAYER_PRELOAD_FIELD_NUMBER: builtins.int
    business: typing.Text
    """业务类型
    archive:视频 live:直播 article:专栏 goods:商品 show:展演
    """

    @property
    def player_preload(self) -> global___PlayerPreloadParams:
        """秒开参数"""
        pass
    def __init__(self,
        *,
        business: typing.Text = ...,
        player_preload: typing.Optional[global___PlayerPreloadParams] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_preload",b"player_preload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business",b"business","player_preload",b"player_preload"]) -> None: ...
global___LatestHistoryReq = LatestHistoryReq

class NoReply(google.protobuf.message.Message):
    """空响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___NoReply = NoReply

class Page(google.protobuf.message.Message):
    """页面信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PN_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    pn: builtins.int
    """当前页码"""

    total: builtins.int
    """总计条目数"""

    def __init__(self,
        *,
        pn: builtins.int = ...,
        total: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pn",b"pn","total",b"total"]) -> None: ...
global___Page = Page

class PlayerPreloadParams(google.protobuf.message.Message):
    """秒开参数"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCEHOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    qn: builtins.int
    """清晰度"""

    fnver: builtins.int
    """流版本"""

    fnval: builtins.int
    """流类型"""

    forceHost: builtins.int
    """是否强制域名"""

    fourk: builtins.int
    """是否4K"""

    def __init__(self,
        *,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        forceHost: builtins.int = ...,
        fourk: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fnval",b"fnval","fnver",b"fnver","forceHost",b"forceHost","fourk",b"fourk","qn",b"qn"]) -> None: ...
global___PlayerPreloadParams = PlayerPreloadParams

class Relation(google.protobuf.message.Message):
    """关系信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUS_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    IS_FOLLOWED_FIELD_NUMBER: builtins.int
    status: builtins.int
    """关系状态
    1:未关注 2:已关注 3:被关注 4:互关
    """

    is_follow: builtins.int
    """用户关注UP主"""

    is_followed: builtins.int
    """UP主关注用户"""

    def __init__(self,
        *,
        status: builtins.int = ...,
        is_follow: builtins.int = ...,
        is_followed: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_follow",b"is_follow","is_followed",b"is_followed","status",b"status"]) -> None: ...
global___Relation = Relation

class SearchReply(google.protobuf.message.Message):
    """搜索历史记录-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEMS_FIELD_NUMBER: builtins.int
    HASMORE_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CursorItem]:
        """卡片内容"""
        pass
    hasMore: builtins.bool
    """是否未拉取完"""

    @property
    def page(self) -> global___Page:
        """页面信息"""
        pass
    def __init__(self,
        *,
        items: typing.Optional[typing.Iterable[global___CursorItem]] = ...,
        hasMore: builtins.bool = ...,
        page: typing.Optional[global___Page] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["page",b"page"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hasMore",b"hasMore","items",b"items","page",b"page"]) -> None: ...
global___SearchReply = SearchReply

class SearchReq(google.protobuf.message.Message):
    """搜索历史记录-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    KEYWORD_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    BUSINESS_FIELD_NUMBER: builtins.int
    keyword: typing.Text
    """关键词"""

    pn: builtins.int
    """页码"""

    business: typing.Text
    """业务类型
    archive:视频 live:直播 article:专栏 goods:商品 show:展演
    """

    def __init__(self,
        *,
        keyword: typing.Text = ...,
        pn: builtins.int = ...,
        business: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["business",b"business","keyword",b"keyword","pn",b"pn"]) -> None: ...
global___SearchReq = SearchReq



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class LaserLogUploadResp(google.protobuf.message.Message):
    """服务端下发日志上报事件"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TASKID_FIELD_NUMBER: builtins.int
    DATE_FIELD_NUMBER: builtins.int
    taskid: builtins.int
    """任务id"""

    date: typing.Text
    """下发时间"""

    def __init__(self,
        *,
        taskid: builtins.int = ...,
        date: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["date",b"date","taskid",b"taskid"]) -> None: ...
global___LaserLogUploadResp = LaserLogUploadResp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pgc/gaetway/vega/v1/vega.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.rpc import status_pb2 as bilibili_dot_rpc_dot_status__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1epgc/gaetway/vega/v1/vega.proto\x12\x13pgc.gateway.vega.v1\x1a\x19\x62ilibili/rpc/status.proto\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\"\t\n\x07\x41uthReq\"\n\n\x08\x41uthResp\"\x97\x01\n\x0b\x46rameOption\x12\x0f\n\x07vega_id\x18\x01 \x01(\x03\x12\x0e\n\x06req_id\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x03\x12\x0e\n\x06is_ack\x18\x04 \x01(\x08\x12$\n\x06status\x18\x05 \x01(\x0b\x32\x14.bilibili.rpc.Status\x12\x12\n\nack_origin\x18\x06 \x01(\t\x12\x0b\n\x03mid\x18\x07 \x01(\x03\"\x0e\n\x0cHeartbeatReq\"\x0f\n\rHeartbeatResp\"U\n\rMessageAckReq\x12\x0f\n\x07vega_id\x18\x01 \x01(\t\x12\x0e\n\x06req_id\x18\x02 \x01(\t\x12\x0e\n\x06origin\x18\x03 \x01(\t\x12\x13\n\x0btarget_path\x18\x04 \x01(\t\"E\n\x0cSubscribeReq\x12\x35\n\x0ctarget_paths\x18\x01 \x03(\x0b\x32\x1f.pgc.gateway.vega.v1.TargetPath\"=\n\nTargetPath\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x04subs\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"\x9d\x01\n\tVegaFrame\x12\x31\n\x07options\x18\x01 \x01(\x0b\x32 .pgc.gateway.vega.v1.FrameOption\x12\x12\n\nroute_path\x18\x02 \x01(\t\x12\"\n\x04\x62ody\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\x12%\n\x07sub_biz\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any2V\n\x04Vega\x12N\n\x0c\x43reateTunnel\x12\x1e.pgc.gateway.vega.v1.VegaFrame\x1a\x1e.pgc.gateway.vega.v1.VegaFrame2\xb9\x02\n\x0cVegaFrameDoc\x12\x43\n\x04\x41uth\x12\x1c.pgc.gateway.vega.v1.AuthReq\x1a\x1d.pgc.gateway.vega.v1.AuthResp\x12R\n\tHeartbeat\x12!.pgc.gateway.vega.v1.HeartbeatReq\x1a\".pgc.gateway.vega.v1.HeartbeatResp\x12H\n\nMessageAck\x12\".pgc.gateway.vega.v1.MessageAckReq\x1a\x16.google.protobuf.Empty\x12\x46\n\tSubscribe\x12!.pgc.gateway.vega.v1.SubscribeReq\x1a\x16.google.protobuf.Emptyb\x06proto3')



_AUTHREQ = DESCRIPTOR.message_types_by_name['AuthReq']
_AUTHRESP = DESCRIPTOR.message_types_by_name['AuthResp']
_FRAMEOPTION = DESCRIPTOR.message_types_by_name['FrameOption']
_HEARTBEATREQ = DESCRIPTOR.message_types_by_name['HeartbeatReq']
_HEARTBEATRESP = DESCRIPTOR.message_types_by_name['HeartbeatResp']
_MESSAGEACKREQ = DESCRIPTOR.message_types_by_name['MessageAckReq']
_SUBSCRIBEREQ = DESCRIPTOR.message_types_by_name['SubscribeReq']
_TARGETPATH = DESCRIPTOR.message_types_by_name['TargetPath']
_VEGAFRAME = DESCRIPTOR.message_types_by_name['VegaFrame']
AuthReq = _reflection.GeneratedProtocolMessageType('AuthReq', (_message.Message,), {
  'DESCRIPTOR' : _AUTHREQ,
  '__module__' : 'pgc.gaetway.vega.v1.vega_pb2'
  # @@protoc_insertion_point(class_scope:pgc.gateway.vega.v1.AuthReq)
  })
_sym_db.RegisterMessage(AuthReq)

AuthResp = _reflection.GeneratedProtocolMessageType('AuthResp', (_message.Message,), {
  'DESCRIPTOR' : _AUTHRESP,
  '__module__' : 'pgc.gaetway.vega.v1.vega_pb2'
  # @@protoc_insertion_point(class_scope:pgc.gateway.vega.v1.AuthResp)
  })
_sym_db.RegisterMessage(AuthResp)

FrameOption = _reflection.GeneratedProtocolMessageType('FrameOption', (_message.Message,), {
  'DESCRIPTOR' : _FRAMEOPTION,
  '__module__' : 'pgc.gaetway.vega.v1.vega_pb2'
  # @@protoc_insertion_point(class_scope:pgc.gateway.vega.v1.FrameOption)
  })
_sym_db.RegisterMessage(FrameOption)

HeartbeatReq = _reflection.GeneratedProtocolMessageType('HeartbeatReq', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEATREQ,
  '__module__' : 'pgc.gaetway.vega.v1.vega_pb2'
  # @@protoc_insertion_point(class_scope:pgc.gateway.vega.v1.HeartbeatReq)
  })
_sym_db.RegisterMessage(HeartbeatReq)

HeartbeatResp = _reflection.GeneratedProtocolMessageType('HeartbeatResp', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEATRESP,
  '__module__' : 'pgc.gaetway.vega.v1.vega_pb2'
  # @@protoc_insertion_point(class_scope:pgc.gateway.vega.v1.HeartbeatResp)
  })
_sym_db.RegisterMessage(HeartbeatResp)

MessageAckReq = _reflection.GeneratedProtocolMessageType('MessageAckReq', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEACKREQ,
  '__module__' : 'pgc.gaetway.vega.v1.vega_pb2'
  # @@protoc_insertion_point(class_scope:pgc.gateway.vega.v1.MessageAckReq)
  })
_sym_db.RegisterMessage(MessageAckReq)

SubscribeReq = _reflection.GeneratedProtocolMessageType('SubscribeReq', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEREQ,
  '__module__' : 'pgc.gaetway.vega.v1.vega_pb2'
  # @@protoc_insertion_point(class_scope:pgc.gateway.vega.v1.SubscribeReq)
  })
_sym_db.RegisterMessage(SubscribeReq)

TargetPath = _reflection.GeneratedProtocolMessageType('TargetPath', (_message.Message,), {
  'DESCRIPTOR' : _TARGETPATH,
  '__module__' : 'pgc.gaetway.vega.v1.vega_pb2'
  # @@protoc_insertion_point(class_scope:pgc.gateway.vega.v1.TargetPath)
  })
_sym_db.RegisterMessage(TargetPath)

VegaFrame = _reflection.GeneratedProtocolMessageType('VegaFrame', (_message.Message,), {
  'DESCRIPTOR' : _VEGAFRAME,
  '__module__' : 'pgc.gaetway.vega.v1.vega_pb2'
  # @@protoc_insertion_point(class_scope:pgc.gateway.vega.v1.VegaFrame)
  })
_sym_db.RegisterMessage(VegaFrame)

_VEGA = DESCRIPTOR.services_by_name['Vega']
_VEGAFRAMEDOC = DESCRIPTOR.services_by_name['VegaFrameDoc']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _AUTHREQ._serialized_start=138
  _AUTHREQ._serialized_end=147
  _AUTHRESP._serialized_start=149
  _AUTHRESP._serialized_end=159
  _FRAMEOPTION._serialized_start=162
  _FRAMEOPTION._serialized_end=313
  _HEARTBEATREQ._serialized_start=315
  _HEARTBEATREQ._serialized_end=329
  _HEARTBEATRESP._serialized_start=331
  _HEARTBEATRESP._serialized_end=346
  _MESSAGEACKREQ._serialized_start=348
  _MESSAGEACKREQ._serialized_end=433
  _SUBSCRIBEREQ._serialized_start=435
  _SUBSCRIBEREQ._serialized_end=504
  _TARGETPATH._serialized_start=506
  _TARGETPATH._serialized_end=567
  _VEGAFRAME._serialized_start=570
  _VEGAFRAME._serialized_end=727
  _VEGA._serialized_start=729
  _VEGA._serialized_end=815
  _VEGAFRAMEDOC._serialized_start=818
  _VEGAFRAMEDOC._serialized_end=1131
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QoeReportReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CANCEL_FIELD_NUMBER: builtins.int
    BUSINESS_TYPE_FIELD_NUMBER: builtins.int
    SCORE_RESULT_FIELD_NUMBER: builtins.int
    BUSINESS_DATA_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    scene: builtins.int
    """"""

    type: builtins.int
    """"""

    cancel: builtins.bool
    """"""

    business_type: typing.Text
    """"""

    @property
    def score_result(self) -> global___QoeScoreResult:
        """"""
        pass
    business_data: typing.Text
    """"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        scene: builtins.int = ...,
        type: builtins.int = ...,
        cancel: builtins.bool = ...,
        business_type: typing.Text = ...,
        score_result: typing.Optional[global___QoeScoreResult] = ...,
        business_data: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["score_result",b"score_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business_data",b"business_data","business_type",b"business_type","cancel",b"cancel","id",b"id","scene",b"scene","score_result",b"score_result","type",b"type"]) -> None: ...
global___QoeReportReq = QoeReportReq

class QoeScoreResult(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SCORE_FIELD_NUMBER: builtins.int
    score: builtins.float
    """"""

    def __init__(self,
        *,
        score: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["score",b"score"]) -> None: ...
global___QoeScoreResult = QoeScoreResult
